//                              --- OpenGL 1.1 ---

#ifndef GL_VERSION_1_1
#define GL_VERSION_1_1 1

/**
 *  @def GLEH_OPENGL_1_1
 *  @brief set if OpenGL 1.1 is supported
 */
#define GLEH_OPENGL_1_1 true

// no new tokens

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  @brief render primitives from array data
 *  @param[in] mode Specifies what kind of primitives to render. Symbolic constants GL_POINTS,
 *      GL_LINE_STRIP, GL_LINE_LOOP, GL_LINES, GL_LINE_STRIP_ADJACENCY, GL_LINES_ADJACENCY,
 *      GL_TRIANGLE_STRIP, GL_TRIANGLE_FAN, GL_TRIANGLES, GL_TRIANGLE_STRIP_ADJACENCY,
 *      GL_TRIANGLES_ADJACENCY and GL_PATCHES are accepted.
 *  @param[in] first Specifies the starting index in the enabled arrays.
 *  @param[in] count Specifies the number of indices to be rendered.
 */
GLStaticApi void ApiEntry glDrawArrays(GLenum mode, int first, GLsizei count);

/**
 *  @brief render primitives from array data
 *  @param[in] mode Specifies what kind of primitives to render. Symbolic constants GL_POINTS,
 *      GL_LINE_STRIP, GL_LINE_LOOP, GL_LINES, GL_LINE_STRIP_ADJACENCY, GL_LINES_ADJACENCY,
 *      GL_TRIANGLE_STRIP, GL_TRIANGLE_FAN, GL_TRIANGLES, GL_TRIANGLE_STRIP_ADJACENCY,
 *      GL_TRIANGLES_ADJACENCY and GL_PATCHES are accepted.
 *  @param[in] count Specifies the number of elements to be rendered.
 *  @param[in] type Specifies the type of the values in indices. Must be one of GL_UNSIGNED_BYTE,
 *      GL_UNSIGNED_SHORT, or GL_UNSIGNED_INT.
 *  @param[in] indices Specifies a pointer to the location where the indices are stored.
 */
GLStaticApi void ApiEntry glDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices);

/**
 *  @brief return the address of the specified pointer
 *  @param[in] pname Specifies the array or buffer pointer to be returned. Symbolic constants
 *      GL_COLOR_ARRAY_POINTER, GL_EDGE_FLAG_ARRAY_POINTER, GL_FOG_COORD_ARRAY_POINTER,
 *      GL_FEEDBACK_BUFFER_POINTER, GL_INDEX_ARRAY_POINTER, GL_NORMAL_ARRAY_POINTER,
 *      GL_SECONDARY_COLOR_ARRAY_POINTER, GL_SELECTION_BUFFER_POINTER,
 *      GL_TEXTURE_COORD_ARRAY_POINTER, or GL_VERTEX_ARRAY_POINTER are accepted.
 *  @param[out] params Returns the pointer value specified by pname.
 */
GLStaticApi void ApiEntry glGetPointerv(GLenum pname, void **params);

/**
 *  @brief set the scale and units used to calculate depth values
 *  @param[in] factor Specifies a scale factor that is used to create a variable depth offset for
 *      each polygon. The initial value is 0.
 *  @param[in] units Is multiplied by an implementation-specific value to create a constant depth
 *      offset. The initial value is 0.
 */
GLStaticApi void ApiEntry glPolygonOffset(float factor, float units);

/**
 *  @brief copy pixels into a 1D texture image
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] internalformat Specifies the internal format of the texture. Must be one of the
 *      following symbolic constants: GL_COMPRESSED_RED, GL_COMPRESSED_RG, GL_COMPRESSED_RGB,
 *      GL_COMPRESSED_RGBA. GL_COMPRESSED_SRGB, GL_COMPRESSED_SRGB_ALPHA. GL_DEPTH_COMPONENT,
 *      GL_DEPTH_COMPONENT16, GL_DEPTH_COMPONENT24, GL_DEPTH_COMPONENT32, GL_RED, GL_RG, GL_RGB,
 *      GL_R3_G3_B2, GL_RGB4, GL_RGB5, GL_RGB8, GL_RGB10, GL_RGB12, GL_RGB16, GL_RGBA, GL_RGBA2,
 *      GL_RGBA4, GL_RGB5_A1, GL_RGBA8, GL_RGB10_A2, GL_RGBA12, GL_RGBA16, GL_SRGB, GL_SRGB8,
 *      GL_SRGB_ALPHA, or GL_SRGB8_ALPHA8.
 *  @param[in] x Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] width Specifies the width of the texture image. Must be 0 or 2 n + 2 border for some
 *      integer n. The height of the texture image is 1.
 *  @param[in] border Specifies the width of the border. Must be either 0 or 1.
 */
GLStaticApi void ApiEntry glCopyTexImage1D(GLenum target, int level, GLenum internalformat, int x, int y, GLsizei width, int border);

/**
 *  @brief copy pixels into a 2D texture image
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] internalformat Specifies the internal format of the texture. Must be one of the
 *      following symbolic constants: GL_COMPRESSED_RED, GL_COMPRESSED_RG, GL_COMPRESSED_RGB,
 *      GL_COMPRESSED_RGBA. GL_COMPRESSED_SRGB, GL_COMPRESSED_SRGB_ALPHA. GL_DEPTH_COMPONENT,
 *      GL_DEPTH_COMPONENT16, GL_DEPTH_COMPONENT24, GL_DEPTH_COMPONENT32, GL_RED, GL_RG, GL_RGB,
 *      GL_R3_G3_B2, GL_RGB4, GL_RGB5, GL_RGB8, GL_RGB10, GL_RGB12, GL_RGB16, GL_RGBA, GL_RGBA2,
 *      GL_RGBA4, GL_RGB5_A1, GL_RGBA8, GL_RGB10_A2, GL_RGBA12, GL_RGBA16, GL_SRGB, GL_SRGB8,
 *      GL_SRGB_ALPHA, or GL_SRGB8_ALPHA8.
 *  @param[in] x Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] width Specifies the width of the texture image. Must be 0 or 2 n + 2 border for some
 *      integer n.
 *  @param[in] height Specifies the height of the texture image. Must be 0 or 2 m + 2 border for
 *      some integer m.
 *  @param[in] border Specifies the width of the border. Must be either 0 or 1.
 */
GLStaticApi void ApiEntry glCopyTexImage2D(GLenum target, int level, GLenum internalformat, int x, int y, GLsizei width, GLsizei height, int border);

/**
 *  @brief copy a one-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies the texel offset within the texture array.
 *  @param[in] x Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] width Specifies the width of the texture subimage.
 */
GLStaticApi void ApiEntry glCopyTexSubImage1D(GLenum target, int level, int xoffset, int x, int y, GLsizei width);

/**
 *  @brief copy a two-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] yoffset Specifies a texel offset in the y direction within the texture array.
 *  @param[in] x Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] height Specifies the height of the texture subimage.
 */
GLStaticApi void ApiEntry glCopyTexSubImage2D(GLenum target, int level, int xoffset, int yoffset, int x, int y, GLsizei width, GLsizei height);

/**
 *  @brief specify a one-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] format Specifies the format of the pixel data. The following symbolic values are
 *      accepted: GL_RED, GL_RG, GL_RGB, GL_BGR, GL_RGBA, and GL_BGRA.
 *  @param[in] type Specifies the data type of the pixel data. The following symbolic values are
 *      accepted: GL_UNSIGNED_BYTE, GL_BYTE, GL_UNSIGNED_SHORT, GL_SHORT, GL_UNSIGNED_INT, GL_INT,
 *      GL_FLOAT, GL_UNSIGNED_BYTE_3_3_2, GL_UNSIGNED_BYTE_2_3_3_REV, GL_UNSIGNED_SHORT_5_6_5,
 *      GL_UNSIGNED_SHORT_5_6_5_REV, GL_UNSIGNED_SHORT_4_4_4_4, GL_UNSIGNED_SHORT_4_4_4_4_REV,
 *      GL_UNSIGNED_SHORT_5_5_5_1, GL_UNSIGNED_SHORT_1_5_5_5_REV, GL_UNSIGNED_INT_8_8_8_8,
 *      GL_UNSIGNED_INT_8_8_8_8_REV, GL_UNSIGNED_INT_10_10_10_2, and GL_UNSIGNED_INT_2_10_10_10_REV.
 *  @param[in] data Specifies a pointer to the image data in memory.
 */
GLStaticApi void ApiEntry glTexSubImage1D(GLenum target, int level, int xoffset, GLsizei width, GLenum format, GLenum type, const void *data);

/**
 *  @brief specify a two-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] yoffset Specifies a texel offset in the y direction within the texture array.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] height Specifies the height of the texture subimage.
 *  @param[in] format Specifies the format of the pixel data. The following symbolic values are
 *      accepted: GL_RED, GL_RG, GL_RGB, GL_BGR, GL_RGBA, and GL_BGRA.
 *  @param[in] type Specifies the data type of the pixel data. The following symbolic values are
 *      accepted: GL_UNSIGNED_BYTE, GL_BYTE, GL_UNSIGNED_SHORT, GL_SHORT, GL_UNSIGNED_INT, GL_INT,
 *      GL_FLOAT, GL_UNSIGNED_BYTE_3_3_2, GL_UNSIGNED_BYTE_2_3_3_REV, GL_UNSIGNED_SHORT_5_6_5,
 *      GL_UNSIGNED_SHORT_5_6_5_REV, GL_UNSIGNED_SHORT_4_4_4_4, GL_UNSIGNED_SHORT_4_4_4_4_REV,
 *      GL_UNSIGNED_SHORT_5_5_5_1, GL_UNSIGNED_SHORT_1_5_5_5_REV, GL_UNSIGNED_INT_8_8_8_8,
 *      GL_UNSIGNED_INT_8_8_8_8_REV, GL_UNSIGNED_INT_10_10_10_2, and GL_UNSIGNED_INT_2_10_10_10_REV.
 *  @param[in] data Specifies a pointer to the image data in memory.
 */
GLStaticApi void ApiEntry glTexSubImage2D(GLenum target, int level, int xoffset, int yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *data);

/**
 *  @brief bind a named texture to a texturing target
 *  @param[in] target Specifies the target to which the texture is bound. Must be either
 *      GL_TEXTURE_1D, GL_TEXTURE_2D, GL_TEXTURE_3D, or GL_TEXTURE_1D_ARRAY, GL_TEXTURE_2D_ARRAY,
 *      GL_TEXTURE_RECTANGLE, GL_TEXTURE_CUBE_MAP, GL_TEXTURE_2D_MULTISAMPLE or GL_TEXTURE_2D_MULTISAMPLE_ARRAY.
 *  @param[in] texture Specifies the name of a texture.
 */
GLStaticApi void ApiEntry glBindTexture(GLenum target, GLuint texture);

/**
 *  @brief delete named textures
 *  @param[in] n Specifies the number of textures to be deleted.
 *  @param[in] textures Specifies an array of textures to be deleted.
 */
GLStaticApi void ApiEntry glDeleteTextures(GLsizei n, const GLuint *textures);

/**
 *  @brief generate texture names
 *  @param[in] n Specifies the number of texture names to be generated.
 *  @param[out] textures Specifies an array in which the generated texture names are stored.
 */
GLStaticApi void ApiEntry glGenTextures(GLsizei n, GLuint *textures);

/**
 *  @brief determine if a name corresponds to a texture
 *  @param[in] texture Specifies a value that may be the name of a texture.
 */
GLStaticApi GLboolean ApiEntry glIsTexture(GLuint texture);

#ifdef __cplusplus
}
#endif

#ifdef __HAVE_GL_AUTOCHECK

inline void glDrawArrays_glachwrap(GLenum mode, int first, GLsizei count) { glDrawArrays(mode,first,count); }
inline void glDrawElements_glachwrap(GLenum mode, GLsizei count, GLenum type, const void *indices) { glDrawElements(mode,count,type,indices); }
inline void glGetPointerv_glachwrap(GLenum pname, void **params) { glGetPointerv(pname,params); }
inline void glPolygonOffset_glachwrap(float factor, float units) { glPolygonOffset(factor,units); }
inline void glCopyTexImage1D_glachwrap(GLenum target, int level, GLenum internalformat, int x, int y, GLsizei width, int border) { glCopyTexImage1D(target,level,internalformat,x,y,width,border); }
inline void glCopyTexImage2D_glachwrap(GLenum target, int level, GLenum internalformat, int x, int y, GLsizei width, GLsizei height, int border) { glCopyTexImage2D(target,level,internalformat,x,y,width,height,border); }
inline void glCopyTexSubImage1D_glachwrap(GLenum target, int level, int xoffset, int x, int y, GLsizei width) { glCopyTexSubImage1D(target,level,xoffset,x,y,width); }
inline void glCopyTexSubImage2D_glachwrap(GLenum target, int level, int xoffset, int yoffset, int x, int y, GLsizei width, GLsizei height) { glCopyTexSubImage2D(target,level,xoffset,yoffset,x,y,width,height); }
inline void glTexSubImage1D_glachwrap(GLenum target, int level, int xoffset, GLsizei width, GLenum format, GLenum type, const void *data) { glTexSubImage1D(target,level,xoffset,width,format,type,data); }
inline void glTexSubImage2D_glachwrap(GLenum target, int level, int xoffset, int yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *data) { glTexSubImage2D(target,level,xoffset,yoffset,width,height,format,type,data); }
inline void glBindTexture_glachwrap(GLenum target, GLuint texture) { glBindTexture(target,texture); }
inline void glDeleteTextures_glachwrap(GLsizei n, const GLuint *textures) { glDeleteTextures(n,textures); }
inline void glGenTextures_glachwrap(GLsizei n, GLuint *textures) { glGenTextures(n,textures); }
inline GLboolean glIsTexture_glachwrap(GLuint texture, const char *p_s_filename, int n_line) { GLboolean result = glIsTexture(texture); GL_AUTOCHECK_BLOCK("glIsTexture", p_s_filename, n_line); return result; }

/**
 *  @def glDrawArrays
 *  @brief render primitives from array data
 *  @param[in] mode Specifies what kind of primitives to render. Symbolic constants GL_POINTS,
 *      GL_LINE_STRIP, GL_LINE_LOOP, GL_LINES, GL_LINE_STRIP_ADJACENCY, GL_LINES_ADJACENCY,
 *      GL_TRIANGLE_STRIP, GL_TRIANGLE_FAN, GL_TRIANGLES, GL_TRIANGLE_STRIP_ADJACENCY,
 *      GL_TRIANGLES_ADJACENCY and GL_PATCHES are accepted.
 *  @param[in] first Specifies the starting index in the enabled arrays.
 *  @param[in] count Specifies the number of indices to be rendered.
 */
#define glDrawArrays(mode,first,count) do { glDrawArrays_glachwrap(mode, first, count); GL_AUTOCHECK_BLOCK("glDrawArrays", __FILE__, __LINE__); } while(0)

/**
 *  @def glDrawElements
 *  @brief render primitives from array data
 *  @param[in] mode Specifies what kind of primitives to render. Symbolic constants GL_POINTS,
 *      GL_LINE_STRIP, GL_LINE_LOOP, GL_LINES, GL_LINE_STRIP_ADJACENCY, GL_LINES_ADJACENCY,
 *      GL_TRIANGLE_STRIP, GL_TRIANGLE_FAN, GL_TRIANGLES, GL_TRIANGLE_STRIP_ADJACENCY,
 *      GL_TRIANGLES_ADJACENCY and GL_PATCHES are accepted.
 *  @param[in] count Specifies the number of elements to be rendered.
 *  @param[in] type Specifies the type of the values in indices. Must be one of GL_UNSIGNED_BYTE,
 *      GL_UNSIGNED_SHORT, or GL_UNSIGNED_INT.
 *  @param[in] indices Specifies a pointer to the location where the indices are stored.
 */
#define glDrawElements(mode,count,type,indices) do { glDrawElements_glachwrap(mode, count, type, indices); GL_AUTOCHECK_BLOCK("glDrawElements", __FILE__, __LINE__); } while(0)

/**
 *  @def glGetPointerv
 *  @brief return the address of the specified pointer
 *  @param[in] pname Specifies the array or buffer pointer to be returned. Symbolic constants
 *      GL_COLOR_ARRAY_POINTER, GL_EDGE_FLAG_ARRAY_POINTER, GL_FOG_COORD_ARRAY_POINTER,
 *      GL_FEEDBACK_BUFFER_POINTER, GL_INDEX_ARRAY_POINTER, GL_NORMAL_ARRAY_POINTER,
 *      GL_SECONDARY_COLOR_ARRAY_POINTER, GL_SELECTION_BUFFER_POINTER,
 *      GL_TEXTURE_COORD_ARRAY_POINTER, or GL_VERTEX_ARRAY_POINTER are accepted.
 *  @param[out] params Returns the pointer value specified by pname.
 */
#define glGetPointerv(pname,params) do { glGetPointerv_glachwrap(pname, params); GL_AUTOCHECK_BLOCK("glGetPointerv", __FILE__, __LINE__); } while(0)

/**
 *  @def glPolygonOffset
 *  @brief set the scale and units used to calculate depth values
 *  @param[in] factor Specifies a scale factor that is used to create a variable depth offset for
 *      each polygon. The initial value is 0.
 *  @param[in] units Is multiplied by an implementation-specific value to create a constant depth
 *      offset. The initial value is 0.
 */
#define glPolygonOffset(factor,units) do { glPolygonOffset_glachwrap(factor, units); GL_AUTOCHECK_BLOCK("glPolygonOffset", __FILE__, __LINE__); } while(0)

/**
 *  @def glCopyTexImage1D
 *  @brief copy pixels into a 1D texture image
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] internalformat Specifies the internal format of the texture. Must be one of the
 *      following symbolic constants: GL_COMPRESSED_RED, GL_COMPRESSED_RG, GL_COMPRESSED_RGB,
 *      GL_COMPRESSED_RGBA. GL_COMPRESSED_SRGB, GL_COMPRESSED_SRGB_ALPHA. GL_DEPTH_COMPONENT,
 *      GL_DEPTH_COMPONENT16, GL_DEPTH_COMPONENT24, GL_DEPTH_COMPONENT32, GL_RED, GL_RG, GL_RGB,
 *      GL_R3_G3_B2, GL_RGB4, GL_RGB5, GL_RGB8, GL_RGB10, GL_RGB12, GL_RGB16, GL_RGBA, GL_RGBA2,
 *      GL_RGBA4, GL_RGB5_A1, GL_RGBA8, GL_RGB10_A2, GL_RGBA12, GL_RGBA16, GL_SRGB, GL_SRGB8,
 *      GL_SRGB_ALPHA, or GL_SRGB8_ALPHA8.
 *  @param[in] x Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] width Specifies the width of the texture image. Must be 0 or 2 n + 2 border for some
 *      integer n. The height of the texture image is 1.
 *  @param[in] border Specifies the width of the border. Must be either 0 or 1.
 */
#define glCopyTexImage1D(target,level,internalformat,x,y,width,border) do { glCopyTexImage1D_glachwrap(target, level, internalformat, x, y, width, border); GL_AUTOCHECK_BLOCK("glCopyTexImage1D", __FILE__, __LINE__); } while(0)

/**
 *  @def glCopyTexImage2D
 *  @brief copy pixels into a 2D texture image
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] internalformat Specifies the internal format of the texture. Must be one of the
 *      following symbolic constants: GL_COMPRESSED_RED, GL_COMPRESSED_RG, GL_COMPRESSED_RGB,
 *      GL_COMPRESSED_RGBA. GL_COMPRESSED_SRGB, GL_COMPRESSED_SRGB_ALPHA. GL_DEPTH_COMPONENT,
 *      GL_DEPTH_COMPONENT16, GL_DEPTH_COMPONENT24, GL_DEPTH_COMPONENT32, GL_RED, GL_RG, GL_RGB,
 *      GL_R3_G3_B2, GL_RGB4, GL_RGB5, GL_RGB8, GL_RGB10, GL_RGB12, GL_RGB16, GL_RGBA, GL_RGBA2,
 *      GL_RGBA4, GL_RGB5_A1, GL_RGBA8, GL_RGB10_A2, GL_RGBA12, GL_RGBA16, GL_SRGB, GL_SRGB8,
 *      GL_SRGB_ALPHA, or GL_SRGB8_ALPHA8.
 *  @param[in] x Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] width Specifies the width of the texture image. Must be 0 or 2 n + 2 border for some
 *      integer n.
 *  @param[in] height Specifies the height of the texture image. Must be 0 or 2 m + 2 border for
 *      some integer m.
 *  @param[in] border Specifies the width of the border. Must be either 0 or 1.
 */
#define glCopyTexImage2D(target,level,internalformat,x,y,width,height,border) do { glCopyTexImage2D_glachwrap(target, level, internalformat, x, y, width, height, border); GL_AUTOCHECK_BLOCK("glCopyTexImage2D", __FILE__, __LINE__); } while(0)

/**
 *  @def glCopyTexSubImage1D
 *  @brief copy a one-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies the texel offset within the texture array.
 *  @param[in] x Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the left corner of the row of pixels to be copied.
 *  @param[in] width Specifies the width of the texture subimage.
 */
#define glCopyTexSubImage1D(target,level,xoffset,x,y,width) do { glCopyTexSubImage1D_glachwrap(target, level, xoffset, x, y, width); GL_AUTOCHECK_BLOCK("glCopyTexSubImage1D", __FILE__, __LINE__); } while(0)

/**
 *  @def glCopyTexSubImage2D
 *  @brief copy a two-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] yoffset Specifies a texel offset in the y direction within the texture array.
 *  @param[in] x Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] y Specify the window coordinates of the lower left corner of the rectangular region
 *      of pixels to be copied.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] height Specifies the height of the texture subimage.
 */
#define glCopyTexSubImage2D(target,level,xoffset,yoffset,x,y,width,height) do { glCopyTexSubImage2D_glachwrap(target, level, xoffset, yoffset, x, y, width, height); GL_AUTOCHECK_BLOCK("glCopyTexSubImage2D", __FILE__, __LINE__); } while(0)

/**
 *  @def glTexSubImage1D
 *  @brief specify a one-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_1D.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] format Specifies the format of the pixel data. The following symbolic values are
 *      accepted: GL_RED, GL_RG, GL_RGB, GL_BGR, GL_RGBA, and GL_BGRA.
 *  @param[in] type Specifies the data type of the pixel data. The following symbolic values are
 *      accepted: GL_UNSIGNED_BYTE, GL_BYTE, GL_UNSIGNED_SHORT, GL_SHORT, GL_UNSIGNED_INT, GL_INT,
 *      GL_FLOAT, GL_UNSIGNED_BYTE_3_3_2, GL_UNSIGNED_BYTE_2_3_3_REV, GL_UNSIGNED_SHORT_5_6_5,
 *      GL_UNSIGNED_SHORT_5_6_5_REV, GL_UNSIGNED_SHORT_4_4_4_4, GL_UNSIGNED_SHORT_4_4_4_4_REV,
 *      GL_UNSIGNED_SHORT_5_5_5_1, GL_UNSIGNED_SHORT_1_5_5_5_REV, GL_UNSIGNED_INT_8_8_8_8,
 *      GL_UNSIGNED_INT_8_8_8_8_REV, GL_UNSIGNED_INT_10_10_10_2, and GL_UNSIGNED_INT_2_10_10_10_REV.
 *  @param[in] data Specifies a pointer to the image data in memory.
 */
#define glTexSubImage1D(target,level,xoffset,width,format,type,data) do { glTexSubImage1D_glachwrap(target, level, xoffset, width, format, type, data); GL_AUTOCHECK_BLOCK("glTexSubImage1D", __FILE__, __LINE__); } while(0)

/**
 *  @def glTexSubImage2D
 *  @brief specify a two-dimensional texture subimage
 *  @param[in] target Specifies the target texture. Must be GL_TEXTURE_2D,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_X, GL_TEXTURE_CUBE_MAP_NEGATIVE_X,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Y, GL_TEXTURE_CUBE_MAP_NEGATIVE_Y,
 *      GL_TEXTURE_CUBE_MAP_POSITIVE_Z, or GL_TEXTURE_CUBE_MAP_NEGATIVE_Z.
 *  @param[in] level Specifies the level-of-detail number. Level 0 is the base image level. Level n
 *      is the nth mipmap reduction image.
 *  @param[in] xoffset Specifies a texel offset in the x direction within the texture array.
 *  @param[in] yoffset Specifies a texel offset in the y direction within the texture array.
 *  @param[in] width Specifies the width of the texture subimage.
 *  @param[in] height Specifies the height of the texture subimage.
 *  @param[in] format Specifies the format of the pixel data. The following symbolic values are
 *      accepted: GL_RED, GL_RG, GL_RGB, GL_BGR, GL_RGBA, and GL_BGRA.
 *  @param[in] type Specifies the data type of the pixel data. The following symbolic values are
 *      accepted: GL_UNSIGNED_BYTE, GL_BYTE, GL_UNSIGNED_SHORT, GL_SHORT, GL_UNSIGNED_INT, GL_INT,
 *      GL_FLOAT, GL_UNSIGNED_BYTE_3_3_2, GL_UNSIGNED_BYTE_2_3_3_REV, GL_UNSIGNED_SHORT_5_6_5,
 *      GL_UNSIGNED_SHORT_5_6_5_REV, GL_UNSIGNED_SHORT_4_4_4_4, GL_UNSIGNED_SHORT_4_4_4_4_REV,
 *      GL_UNSIGNED_SHORT_5_5_5_1, GL_UNSIGNED_SHORT_1_5_5_5_REV, GL_UNSIGNED_INT_8_8_8_8,
 *      GL_UNSIGNED_INT_8_8_8_8_REV, GL_UNSIGNED_INT_10_10_10_2, and GL_UNSIGNED_INT_2_10_10_10_REV.
 *  @param[in] data Specifies a pointer to the image data in memory.
 */
#define glTexSubImage2D(target,level,xoffset,yoffset,width,height,format,type,data) do { glTexSubImage2D_glachwrap(target, level, xoffset, yoffset, width, height, format, type, data); GL_AUTOCHECK_BLOCK("glTexSubImage2D", __FILE__, __LINE__); } while(0)

/**
 *  @def glBindTexture
 *  @brief bind a named texture to a texturing target
 *  @param[in] target Specifies the target to which the texture is bound. Must be either
 *      GL_TEXTURE_1D, GL_TEXTURE_2D, GL_TEXTURE_3D, or GL_TEXTURE_1D_ARRAY, GL_TEXTURE_2D_ARRAY,
 *      GL_TEXTURE_RECTANGLE, GL_TEXTURE_CUBE_MAP, GL_TEXTURE_2D_MULTISAMPLE or GL_TEXTURE_2D_MULTISAMPLE_ARRAY.
 *  @param[in] texture Specifies the name of a texture.
 */
#define glBindTexture(target,texture) do { glBindTexture_glachwrap(target, texture); GL_AUTOCHECK_BLOCK("glBindTexture", __FILE__, __LINE__); } while(0)

/**
 *  @def glDeleteTextures
 *  @brief delete named textures
 *  @param[in] n Specifies the number of textures to be deleted.
 *  @param[in] textures Specifies an array of textures to be deleted.
 */
#define glDeleteTextures(n,textures) do { glDeleteTextures_glachwrap(n, textures); GL_AUTOCHECK_BLOCK("glDeleteTextures", __FILE__, __LINE__); } while(0)

/**
 *  @def glGenTextures
 *  @brief generate texture names
 *  @param[in] n Specifies the number of texture names to be generated.
 *  @param[out] textures Specifies an array in which the generated texture names are stored.
 */
#define glGenTextures(n,textures) do { glGenTextures_glachwrap(n, textures); GL_AUTOCHECK_BLOCK("glGenTextures", __FILE__, __LINE__); } while(0)

/**
 *  @def glIsTexture
 *  @brief determine if a name corresponds to a texture
 *  @param[in] texture Specifies a value that may be the name of a texture.
 */
#define glIsTexture(texture) glIsTexture_glachwrap(texture, __FILE__, __LINE__)

#endif // __HAVE_GL_AUTOCHECK

#endif // GL_VERSION_1_1

//                              --- ~OpenGL 1.1 ---

