//                              --- OpenGL 3.1 ---

#ifndef GL_VERSION_3_1
#define GL_VERSION_3_1 1
#define __GENERATE_GL_31__

extern bool GLEH_OPENGL_3_1; /**< @brief set if OpenGL 3.1 is supported */

#define GL_SAMPLER_2D_RECT                                          0x8B63
#define GL_SAMPLER_2D_RECT_SHADOW                                   0x8B64
#define GL_SAMPLER_BUFFER                                           0x8DC2
#define GL_INT_SAMPLER_2D_RECT                                      0x8DCD
#define GL_INT_SAMPLER_BUFFER                                       0x8DD0
#define GL_UNSIGNED_INT_SAMPLER_2D_RECT                             0x8DD5
#define GL_UNSIGNED_INT_SAMPLER_BUFFER                              0x8DD8
#define GL_TEXTURE_BUFFER                                           0x8C2A
#define GL_MAX_TEXTURE_BUFFER_SIZE                                  0x8C2B
#define GL_TEXTURE_BINDING_BUFFER                                   0x8C2C
#define GL_TEXTURE_BUFFER_DATA_STORE_BINDING                        0x8C2D
#define GL_TEXTURE_BUFFER_FORMAT                                    0x8C2E
#define GL_TEXTURE_RECTANGLE                                        0x84F5
#define GL_TEXTURE_BINDING_RECTANGLE                                0x84F6
#define GL_PROXY_TEXTURE_RECTANGLE                                  0x84F7
#define GL_MAX_RECTANGLE_TEXTURE_SIZE                               0x84F8
#define GL_RED_SNORM                                                0x8F90
#define GL_RG_SNORM                                                 0x8F91
#define GL_RGB_SNORM                                                0x8F92
#define GL_RGBA_SNORM                                               0x8F93
#define GL_R8_SNORM                                                 0x8F94
#define GL_RG8_SNORM                                                0x8F95
#define GL_RGB8_SNORM                                               0x8F96
#define GL_RGBA8_SNORM                                              0x8F97
#define GL_R16_SNORM                                                0x8F98
#define GL_RG16_SNORM                                               0x8F99
#define GL_RGB16_SNORM                                              0x8F9A
#define GL_RGBA16_SNORM                                             0x8F9B
#define GL_SIGNED_NORMALIZED                                        0x8F9C
#define GL_PRIMITIVE_RESTART                                        0x8F9D
#define GL_PRIMITIVE_RESTART_INDEX                                  0x8F9E

/* Reuse tokens from ARB_copy_buffer */
/* Would reuse tokens from ARB_draw_instanced, but it has none */
/* Reuse tokens from ARB_uniform_buffer_object */

/**
 *  @brief attach the storage for a buffer object to the active buffer texture
 *  @param[in] target Specifies the target of the operation and must be GL_TEXTURE_BUFFER.
 *  @param[in] internalFormat Specifies the internal format of the data in the store belonging to buffer.
 *  @param[in] buffer Specifies the name of the buffer object whose storage to attach to the active
 *      buffer texture.
 */
extern void (GLApi *GLFuncPtrName(glTexBuffer))(GLenum target, GLenum internalFormat, GLuint buffer);

/**
 *  @brief specify the primitive restart index
 *  @param[in] index Specifies the value to be interpreted as the primitive restart index.
 */
extern void (GLApi *GLFuncPtrName(glPrimitiveRestartIndex))(GLuint index);

/**
 *  @def glTexBuffer
 *  @brief attach the storage for a buffer object to the active buffer texture
 *  @param[in] target Specifies the target of the operation and must be GL_TEXTURE_BUFFER.
 *  @param[in] internalFormat Specifies the internal format of the data in the store belonging to buffer.
 *  @param[in] buffer Specifies the name of the buffer object whose storage to attach to the active
 *      buffer texture.
 */
#define glTexBuffer(target,internalFormat,buffer) do { GLFuncPtrName(glTexBuffer)(target, internalFormat, buffer); GL_AUTOCHECK_BLOCK("glTexBuffer", __FILE__, __LINE__); } while(0)

/**
 *  @def glPrimitiveRestartIndex
 *  @brief specify the primitive restart index
 *  @param[in] index Specifies the value to be interpreted as the primitive restart index.
 */
#define glPrimitiveRestartIndex(index) do { GLFuncPtrName(glPrimitiveRestartIndex)(index); GL_AUTOCHECK_BLOCK("glPrimitiveRestartIndex", __FILE__, __LINE__); } while(0)

#endif // GL_VERSION_3_1

//                              --- ~OpenGL 3.1 ---

