//                              --- OpenGL 3.2 ---

#ifndef GL_VERSION_3_2
#define GL_VERSION_3_2 1
#define __GENERATE_GL_32__

extern bool GLEH_OPENGL_3_2; /**< @brief set if OpenGL 3.2 is supported */

#define GL_CONTEXT_CORE_PROFILE_BIT                                 0x00000001
#define GL_CONTEXT_COMPATIBILITY_PROFILE_BIT                        0x00000002
#define GL_LINES_ADJACENCY                                          0x000A
#define GL_LINE_STRIP_ADJACENCY                                     0x000B
#define GL_TRIANGLES_ADJACENCY                                      0x000C
#define GL_TRIANGLE_STRIP_ADJACENCY                                 0x000D
#define GL_PROGRAM_POINT_SIZE                                       0x8642
#define GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS                         0x8C29
#define GL_FRAMEBUFFER_ATTACHMENT_LAYERED                           0x8DA7
#define GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS                     0x8DA8
#define GL_GEOMETRY_SHADER                                          0x8DD9
#define GL_GEOMETRY_VERTICES_OUT                                    0x8916
#define GL_GEOMETRY_INPUT_TYPE                                      0x8917
#define GL_GEOMETRY_OUTPUT_TYPE                                     0x8918
#define GL_MAX_GEOMETRY_UNIFORM_COMPONENTS                          0x8DDF
#define GL_MAX_GEOMETRY_OUTPUT_VERTICES                             0x8DE0
#define GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS                     0x8DE1
#define GL_MAX_VERTEX_OUTPUT_COMPONENTS                             0x9122
#define GL_MAX_GEOMETRY_INPUT_COMPONENTS                            0x9123
#define GL_MAX_GEOMETRY_OUTPUT_COMPONENTS                           0x9124
#define GL_MAX_FRAGMENT_INPUT_COMPONENTS                            0x9125
#define GL_CONTEXT_PROFILE_MASK                                     0x9126
/* reuse GL_MAX_VARYING_COMPONENTS (OpenGL 3.0 core) */
/* reuse GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER (GL_ARB_framebuffer_object) */
/* Reuse tokens from ARB_depth_clamp */
/* Would reuse tokens from ARB_draw_elements_base_vertex, but it has none */
/* Would reuse tokens from ARB_fragment_coord_conventions, but it has none */
/* Reuse tokens from ARB_provoking_vertex */
/* Reuse tokens from ARB_seamless_cube_map */
/* Reuse tokens from ARB_sync */
/* Reuse tokens from ARB_texture_multisample */
/* Don't need to reuse tokens from ARB_vertex_array_bgra since they're already in 1.2 core */

/**
 *  @brief return the value or values of a selected parameter
 *  @param[in] pname Specifies the parameter value to be returned. The symbolic constants in the
 *      list below are accepted.
 *  @param[in] index Specifies the index of the particular element being queried.
 *  @param[out] data Returns the value or values of the specified parameter.
 */
extern void (GLApi *GLFuncPtrName(glGetInteger64i_v))(GLenum pname, GLuint index, GLint64 *data);

/**
 *  @brief return parameters of a buffer object
 *  @param[in] target Specifies the target buffer object. The symbolic constant must be
 *      GL_ARRAY_BUFFER, GL_COPY_READ_BUFFER, GL_COPY_WRITE_BUFFER, GL_ELEMENT_ARRAY_BUFFER,
 *      GL_PIXEL_PACK_BUFFER, GL_PIXEL_UNPACK_BUFFER, GL_TEXTURE_BUFFER,
 *      GL_TRANSFORM_FEEDBACK_BUFFER, or GL_UNIFORM_BUFFER.
 *  @param[in] value Specifies the symbolic name of a buffer object parameter. Accepted values are
 *      GL_BUFFER_ACCESS, GL_BUFFER_MAPPED, GL_BUFFER_SIZE, or GL_BUFFER_USAGE.
 *  @param[out] data Returns the requested parameter.
 */
extern void (GLApi *GLFuncPtrName(glGetBufferParameteri64v))(GLenum target, GLenum value, GLint64 *data);

/**
 *  @brief specify a parameter for a program object
 *  @param[in] program Specifies the name of a program object whose parameter to modify.
 *  @param[in] pname Specifies the name of the parameter to modify.
 *  @param[in] value Specifies the new value of the parameter specified by pname for program.
 */
extern void (GLApi *GLFuncPtrName(glProgramParameteri))(GLuint program, GLenum pname, int value);

/**
 *  @brief attach a level of a texture object as a logical buffer to the currently bound framebuffer object
 *  @param[in] target Specifies the framebuffer target. target must be GL_DRAW_FRAMEBUFFER,
 *      GL_READ_FRAMEBUFFER, or GL_FRAMEBUFFER. GL_FRAMEBUFFER is equivalent to GL_DRAW_FRAMEBUFFER.
 *  @param[in] attachment Specifies the attachment point of the framebuffer. attachment must be
 *      GL_COLOR_ATTACHMENT i, GL_DEPTH_ATTACHMENT, GL_STENCIL_ATTACHMENT or GL_DEPTH_STENCIL_ATTACHMMENT.
 *  @param[in] texture Specifies the texture object to attach to the framebuffer attachment point
 *      named by attachment.
 *  @param[in] level Specifies the mipmap level of texture to attach.
 */
extern void (GLApi *GLFuncPtrName(glFramebufferTexture))(GLenum target, GLenum attachment, GLuint texture, int level);

/**
 *  @def glGetInteger64i_v
 *  @brief return the value or values of a selected parameter
 *  @param[in] pname Specifies the parameter value to be returned. The symbolic constants in the
 *      list below are accepted.
 *  @param[in] index Specifies the index of the particular element being queried.
 *  @param[out] data Returns the value or values of the specified parameter.
 */
#define glGetInteger64i_v(pname,index,data) do { GLFuncPtrName(glGetInteger64i_v)(pname, index, data); GL_AUTOCHECK_BLOCK("glGetInteger64i_v", __FILE__, __LINE__); } while(0)

/**
 *  @def glGetBufferParameteri64v
 *  @brief return parameters of a buffer object
 *  @param[in] target Specifies the target buffer object. The symbolic constant must be
 *      GL_ARRAY_BUFFER, GL_COPY_READ_BUFFER, GL_COPY_WRITE_BUFFER, GL_ELEMENT_ARRAY_BUFFER,
 *      GL_PIXEL_PACK_BUFFER, GL_PIXEL_UNPACK_BUFFER, GL_TEXTURE_BUFFER,
 *      GL_TRANSFORM_FEEDBACK_BUFFER, or GL_UNIFORM_BUFFER.
 *  @param[in] value Specifies the symbolic name of a buffer object parameter. Accepted values are
 *      GL_BUFFER_ACCESS, GL_BUFFER_MAPPED, GL_BUFFER_SIZE, or GL_BUFFER_USAGE.
 *  @param[out] data Returns the requested parameter.
 */
#define glGetBufferParameteri64v(target,value,data) do { GLFuncPtrName(glGetBufferParameteri64v)(target, value, data); GL_AUTOCHECK_BLOCK("glGetBufferParameteri64v", __FILE__, __LINE__); } while(0)

/**
 *  @def glProgramParameteri
 *  @brief specify a parameter for a program object
 *  @param[in] program Specifies the name of a program object whose parameter to modify.
 *  @param[in] pname Specifies the name of the parameter to modify.
 *  @param[in] value Specifies the new value of the parameter specified by pname for program.
 */
#define glProgramParameteri(program,pname,value) do { GLFuncPtrName(glProgramParameteri)(program, pname, value); GL_AUTOCHECK_BLOCK("glProgramParameteri", __FILE__, __LINE__); } while(0)

/**
 *  @def glFramebufferTexture
 *  @brief attach a level of a texture object as a logical buffer to the currently bound framebuffer object
 *  @param[in] target Specifies the framebuffer target. target must be GL_DRAW_FRAMEBUFFER,
 *      GL_READ_FRAMEBUFFER, or GL_FRAMEBUFFER. GL_FRAMEBUFFER is equivalent to GL_DRAW_FRAMEBUFFER.
 *  @param[in] attachment Specifies the attachment point of the framebuffer. attachment must be
 *      GL_COLOR_ATTACHMENT i, GL_DEPTH_ATTACHMENT, GL_STENCIL_ATTACHMENT or GL_DEPTH_STENCIL_ATTACHMMENT.
 *  @param[in] texture Specifies the texture object to attach to the framebuffer attachment point
 *      named by attachment.
 *  @param[in] level Specifies the mipmap level of texture to attach.
 */
#define glFramebufferTexture(target,attachment,texture,level) do { GLFuncPtrName(glFramebufferTexture)(target, attachment, texture, level); GL_AUTOCHECK_BLOCK("glFramebufferTexture", __FILE__, __LINE__); } while(0)

#endif // GL_VERSION_3_2

//                              --- ~OpenGL 3.2 ---

